@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 import unittest
 from datetime import datetime
+
 from convertdate import holidays, julian
 
 
 class TestHolidays(unittest.TestCase):
-
     def setUp(self):
         self.h = holidays.Holidays(2015)
 
@@ -21,7 +21,7 @@ class TestHolidays(unittest.TestCase):
         h = holidays.Holidays(2014)
         self.assertEqual(h.christmas, (2014, 12, 25))
         assert h.thanksgiving == (2014, 11, 27)
-        assert h.columbus_day == (2014, 10, 13)
+        assert h.indigenous_peoples_day == (2014, 10, 13)
 
         assert h.independence_day == (2014, 7, 4)
 
@@ -35,14 +35,12 @@ class TestHolidays(unittest.TestCase):
         self.assertEqual(self.h.fathers_day, (2015, 6, 21))
 
     def test_class(self):
-
-        H = holidays.Holidays()
-        assert H.year == datetime.now().year
+        h = holidays.Holidays()
+        assert h.year == datetime.now().year
         assert str(self.h) == 'Holidays(2015)'
 
-        H.set_year(2010)
-
-        assert H.year == 2010
+        h.set_year(2010)
+        assert h.year == 2010
 
     def test_events(self):
         assert holidays.new_years(2013) == (2013, 1, 1)
@@ -58,7 +56,7 @@ class TestHolidays(unittest.TestCase):
 
         assert holidays.may_day(2015) == (2015, 5, 1)
 
-        assert holidays.columbus_day(2015, 'canada') == (2015, 10, 12)
+        assert holidays.indigenous_peoples_day(2015, 'canada') == (2015, 10, 12)
 
         assert holidays.independence_day(2015) == (2015, 7, 4)
         assert holidays.independence_day(2015, True) == (2015, 7, 3)
@@ -115,7 +113,7 @@ class TestHolidays(unittest.TestCase):
             (2032, 3, 28),
             (2033, 4, 17),
             (2034, 4, 9),
-            (2345, 4, 22)
+            (2345, 4, 22),
         ]
 
         for y, m, d in easters:
@@ -165,7 +163,7 @@ class TestHolidays(unittest.TestCase):
             (2038, 4, 25),
             (2039, 4, 17),
             (2056, 4, 9),
-            (2156, 4, 11)
+            (2156, 4, 11),
         ]
 
         for y, m, d in easters:
@@ -177,7 +175,23 @@ class TestHolidays(unittest.TestCase):
     def testNonChalcedonian(self):
         # In these years, Orthodox Easter falls on 6 April (Julian),
         # but Non-Chalcedonian churches celebrate it a week later on 13 Aprail
-        years = 570, 665, 760, 1007, 1102, 1197, 1292, 1539, 1634, 1729, 1824, 2071, 2166, 2261, 2356
+        years = (
+            570,
+            665,
+            760,
+            1007,
+            1102,
+            1197,
+            1292,
+            1539,
+            1634,
+            1729,
+            1824,
+            2071,
+            2166,
+            2261,
+            2356,
+        )
 
         for y in years:
             orthodox = julian.from_gregorian(*holidays.easter(y, "orthodox"))
@@ -189,17 +203,10 @@ class TestHolidays(unittest.TestCase):
         for y in years:
             self.assertEqual(holidays.easter(y + 1, "orthodox"), holidays.easter(y + 1, "eastern"))
 
-
     def test_jewish_holidays(self):
         # http://www.chabad.org/holidays/passover/pesach_cdo/aid/671901/jewish/When-is-Passover-in-2013-2014-2015-2016-and-2017.htm
         # the date here is the start of the holiday, so the eve=1 option is used
-        passovers = [
-            (2013, 3, 25),
-            (2014, 4, 14),
-            (2015, 4, 3),
-            (2016, 4, 22),
-            (2017, 4, 10)
-        ]
+        passovers = [(2013, 3, 25), (2014, 4, 14), (2015, 4, 3), (2016, 4, 22), (2017, 4, 10)]
         for y, m, d in passovers:
             self.assertEqual(holidays.passover(y, eve=1), (y, m, d))
 
@@ -225,25 +232,34 @@ class TestHolidays(unittest.TestCase):
         for y, m, d in sukkots:
             self.assertEqual(holidays.sukkot(y, eve=0), (y, m, d))
 
-        shavuots = [
-            (2016, 6, 12),
-            (2015, 5, 24)
-        ]
+        shavuots = [(2016, 6, 12), (2015, 5, 24)]
         for y, m, d in shavuots:
             self.assertEqual(holidays.shavuot(y, eve=0), (y, m, d))
 
-        purims = [
-            (2017, 3, 12),
-            (2016, 3, 24)
-        ]
+        purims = [(2017, 3, 12), (2016, 3, 24)]
         for y, m, d in purims:
             self.assertEqual(holidays.purim(y, eve=0), (y, m, d))
 
+        tisha_bavs = [
+            (2019, 8, 11),
+            (2020, 7, 30),
+            (2021, 7, 18),
+            (2022, 8, 7),
+            (2023, 7, 27),
+        ]
+        for y, m, d in tisha_bavs:
+            self.assertEqual(holidays.tisha_bav(y, eve=0), (y, m, d))
+
         assert self.h.hanukkah == (2015, 12, 7)
         assert self.h.rosh_hashanah == (2015, 9, 14)
         assert self.h.yom_kippur == (2015, 9, 23)
         assert self.h.passover == (2015, 4, 4)
 
+        assert self.h.tisha_bav == (2015, 7, 26)
+        assert self.h.shemini_azeret == (2015, 10, 5)
+        assert self.h.lag_baomer == (2015, 5, 7)
+        assert self.h.tu_beshvat == (2015, 2, 4)
+
     def test_mexican_holidays(self):
         self.assertEqual(holidays.natalicio_benito_juarez(2015, False), (2015, 3, 21))
         self.assertEqual(holidays.natalicio_benito_juarez(2015), (2015, 3, 16))
@@ -262,10 +278,40 @@ class TestHolidays(unittest.TestCase):
         assert self.h.lincolns_birthday == (2015, 2, 12)
         assert self.h.memorial_day == (2015, 5, 25)
         assert self.h.labor_day == (2015, 9, 7)
-        assert self.h.columbus_day == (2015, 10, 12)
+        assert self.h.indigenous_peoples_day == (2015, 10, 12)
         assert self.h.veterans_day == (2015, 11, 11)
         assert self.h.martin_luther_king_day == (2015, 1, 19)
 
+    def test_usa_holidays_observed(self):
+        self.assertSequenceEqual(holidays.independence_day(2015), (2015, 7, 4))
+        assert holidays.independence_day(2015, True) == (2015, 7, 3)
+        assert holidays.washingtons_birthday(2015) == (2015, 2, 22)
+        assert holidays.washingtons_birthday(2015, True) == (2015, 2, 16)
+        assert holidays.washingtons_birthday(2020, True) == (2020, 2, 17)
+        assert holidays.new_years(2022, True) == (2021, 12, 31)
+        self.assertSequenceEqual(holidays.christmas(2021, True), (2021, 12, 24))
 
-if __name__ == '__main__':
-    unittest.main()
+    def test_deprecated_columbus_day(self):
+        with self.assertRaises(DeprecationWarning):
+            holidays.columbus_day(2020)
+
+    def test_islamic_holidays(self):
+        """Test the dates of certain Islamic holidays."""
+        holidays_2015 = {
+            'eid_aladha': (2015, 9, 24),
+            'ramadan': (2015, 6, 18),
+            'eid_alfitr': (2015, 7, 18),
+        }
+        with self.subTest():
+            for name, date in holidays_2015.items():
+                self.assertEqual(getattr(self.h, name), date, name)
+
+        h21 = holidays.Holidays(2021)
+        holidays_2021 = {
+            'eid_aladha': (2021, 7, 20),
+            'ramadan': (2021, 4, 13),
+            'eid_alfitr': (2021, 5, 13),
+        }
+        with self.subTest():
+            for name, date in holidays_2021.items():
+                self.assertEqual(getattr(h21, name), date, name)
